.. highlight:: shell

============
Installation
============


Stable release
--------------

. Use pip to install from `PyPI <https://pypi.org/project/geocube/>`__:

  .. code-block:: bash
    
      pip install geocube


2. Use `conda <https://conda.io/en/latest/>`__ with the `conda-forge <https://conda-forge.org/>`__ channel:

  .. code-block:: bash

      conda install -c conda-forge geocube


From source
-----------

The source for geocube can be downloaded from the `GitHub repo`_.

.. code-block:: console

    $ git clone git@github.com:corteva/geocube.git

    $ cd geocube
    $ python setup.py install


.. _GitHub repo: https://github.com/corteva/geocube
